==> DyWorld_0.8.6.zip: DyWorld_0.8.6/data/core/functions/colors.lua <==
-- color tiers
Color_Tier = {
	[1] = {r=165, g=42, b=42}, --brown
	[2] = {r=255, g=255, b=0}, --yellow
	[3] = {r=128, g=0, b=128}, --purple
	[4] = {r=0, g=255, b=0}, --green
	[5] = {r=0, g=0, b=255}, --blue
	[6] = {r=255, g=0, b=0}, --red
	[7] = {r=0, g=255, b=255}, --cyan
	[8] = {r=255, g=165, b=0}, --orange
	[9] = {r=255, g=192, b=203}, --pink
	[10] = {r=255, g=192, b=203}, --pink
	["Dirty"] = {r = 165, g = 165, b = 165},
}

Material_Colors = {
	--- Tier 1 ---
	["wood"] = {r=182, g=155, b=76},
	["stone"] = {r=141, g=91, b=74},
	["coal"] = {r=10, g=8, b=9}, 
	["sand"] = {r=242, g=244, b=212}, 
	--- Tier 2 ---
	["iron"] = {r=82, g=174, b=212}, -- 52aed4
	["copper"] = {r=212, g=119, b=82}, -- d47752
	["tin"] = {r=39, g=105, b=135}, -- 276987
	["silver"] = {r=170, g=170, b=170}, -- aaaaaa
	--- Tier 3 ---
	["steel"] = {r=229, g=227, b=227}, -- e5e3e3
	["nickel"] = {r=92, g=114, b=208}, -- 5c72d0
	["lead"] = {r=105, g=213, b=212}, -- 69d5d4
	["gold"] = {r=134, g=128, b=34}, -- 868022
	["bronze"] = {r=126, g=112, b=109}, -- 7e706d
	--- Tier 4 ---
	["uranium"] = {r=21, g=121, b=10}, -- 15790a
	["electrum"] = {r=146, g=135, b=41}, -- 928729
	["invar"] = {r=87, g=144, b=210}, -- 
	["cobalt"] = {r=77, g=166, b=255}, -- 4DA6FF
	--- Tier 5 ---
	["stainless-steel"] = {r=196, g=124, b=126}, -- c47c7e
	["arditium"] = {r=102, g=102, b=0}, -- 666600
	--- Tier 6 ---
	["tungsten"] = {r=87, g=87, b=87}, -- 575757
	["titanium"] = {r=57, g=61, b=112}, -- 393d70
	--- Tier 7 ---
	["electranium"] = {r=124, g=119, b=21}, -- 
	["arditium-tungstenate"] = {r=95, g=95, b=44}, --
	--- Tier 8 ---
	["tungstvar"] = {r=87, g=116, b=149}, -- 
	--- Tier 9 ---
	["neutronium"] = {r=54, g=50, b=76}, -- 04001A
	--- Tier 10 ---
	["neutrobaltium"] = {r=128, g=128, b=128}, -- TO DO
	--- Unused ---
	--[[Rubber = {r=128, g=128, b=128},
	Chitin = {r=228, g=128, b=128},
	Obsidian = {r=105, g=105, b=105},
	Chromium = {r=200, g=56, b=60}, -- c8383c
	Zinc = {r=97, g=208, b=92}, -- 61d05c
	Aluminium = {r=150, g=150, b=150}, -- 969696
	Lithium = {r=204, g=204, b=217}, -- ccccd9
	Billon = {r=191, g=145, b=126}, -- bf917e
	Copper_Tungsten = {r=137, g=135, b=142}, -- 89878e
	Copper_Hydride = {r=212, g=179, b=123}, -- d4b37b
	Lithium_Titaniate = {r=142, g=142, b=160}, -- 8e8ea0
	Elinvar = {r=125, g=115, b=160}, -- 7d73a0
	Stainless_Copilinvar_Tungstate = {r=153, g=124, b=143}, -- 997c8f]]--
}

==> DyWorld_0.9.2.zip: DyWorld_0.9.2/data/core/functions/colors.lua <==
-- color tiers
Color_Tier = {
	[1] = {r=165, g=42, b=42}, --brown
	[2] = {r=255, g=255, b=0}, --yellow
	[3] = {r=128, g=0, b=128}, --purple
	[4] = {r=0, g=255, b=0}, --green
	[5] = {r=0, g=0, b=255}, --blue
	[6] = {r=255, g=0, b=0}, --red
	[7] = {r=0, g=255, b=255}, --cyan
	[8] = {r=255, g=165, b=0}, --orange
	[9] = {r=255, g=192, b=203}, --pink
	[10] = {r=255, g=192, b=203}, --pink
	["Dirty"] = {r = 165, g = 165, b = 165},
}

Material_Colors = {
	--- Tier 1 ---
	["wood"] = {r=182, g=155, b=76},
	["stone"] = {r=141, g=91, b=74},
	["coal"] = {r=10, g=8, b=9}, 
	["sand"] = {r=242, g=244, b=212}, 
	--- Tier 2 ---
	["iron"] = {r=82, g=174, b=212}, -- 52aed4
	["copper"] = {r=212, g=119, b=82}, -- d47752
	["tin"] = {r=39, g=105, b=135}, -- 276987
	["silver"] = {r=170, g=170, b=170}, -- aaaaaa
	--- Tier 3 ---
	["steel"] = {r=229, g=227, b=227}, -- e5e3e3
	["nickel"] = {r=92, g=114, b=208}, -- 5c72d0
	["lead"] = {r=105, g=213, b=212}, -- 69d5d4
	["gold"] = {r=134, g=128, b=34}, -- 868022
	["bronze"] = {r=126, g=112, b=109}, -- 7e706d
	--- Tier 4 ---
	["uranium"] = {r=21, g=121, b=10}, -- 15790a
	["electrum"] = {r=146, g=135, b=41}, -- 928729
	["invar"] = {r=87, g=144, b=210}, -- 
	["cobalt"] = {r=77, g=166, b=255}, -- 4DA6FF
	--- Tier 5 ---
	["stainless-steel"] = {r=196, g=124, b=126}, -- c47c7e
	["arditium"] = {r=102, g=102, b=0}, -- 666600
	--- Tier 6 ---
	["tungsten"] = {r=87, g=87, b=87}, -- 575757
	["titanium"] = {r=57, g=61, b=112}, -- 393d70
	--- Tier 7 ---
	["electranium"] = {r=124, g=119, b=21}, -- 
	["arditium-tungstenate"] = {r=95, g=95, b=44}, --
	--- Tier 8 ---
	["tungstvar"] = {r=87, g=116, b=149}, -- 
	--- Tier 9 ---
	["neutronium"] = {r=54, g=50, b=76}, -- 04001A
	--- Tier 10 ---
	["neutrobaltium"] = {r=128, g=128, b=128}, -- TO DO
	--- Unused ---
	--[[Rubber = {r=128, g=128, b=128},
	Chitin = {r=228, g=128, b=128},
	Obsidian = {r=105, g=105, b=105},
	Chromium = {r=200, g=56, b=60}, -- c8383c
	Zinc = {r=97, g=208, b=92}, -- 61d05c
	Aluminium = {r=150, g=150, b=150}, -- 969696
	Lithium = {r=204, g=204, b=217}, -- ccccd9
	Billon = {r=191, g=145, b=126}, -- bf917e
	Copper_Tungsten = {r=137, g=135, b=142}, -- 89878e
	Copper_Hydride = {r=212, g=179, b=123}, -- d4b37b
	Lithium_Titaniate = {r=142, g=142, b=160}, -- 8e8ea0
	Elinvar = {r=125, g=115, b=160}, -- 7d73a0
	Stainless_Copilinvar_Tungstate = {r=153, g=124, b=143}, -- 997c8f]]--
}

Damage_Color = {
	["nuclear"] = {r=0.49, g=1, b=0.51, a=1},
	["electric"] = {r=0.49, g=0.46, b=0.9, a=1},
	["poison"] = {r=0.49, g=1, b=0.51, a=1},
	["acid"] = {r=0.49, g=1, b=0.51, a=1},
	["gas"] = {r=0.32, g=0.23, b=0.32, a=1},
	["water"] = {r=0.12, g=0.12, b=1, a=1},
	["fire"] = {r=1, g=0.12, b=0.12, a=1},
	["lightning"] = {r=0.12, g=0.12, b=0.8, a=1},
	["fungal"] = {r=0.8, g=1, b=0.51, a=1},
	["plasma"] = {r=0.12, g=0.8, b=0.8, a=1},
	["laser"] = {r=1, g=1, b=0.51, a=1},
	["lava"] = {r=1, g=0.30, b=0.30, a=1},
	["earth"] = {r=0.49, g=0.9, b=0.9, a=1},
	["fission"] = {r=0.02, g=0.02, b=0.02, a=1},
	["chemical"] = {r=0.24, g=0.42, b=0.24, a=1},
	["physical"] = {r=0.49, g=0.46, b=0.51, a=1},
	["explosion"] = {r=0.75, g=0.46, b=0.39, a=1},
	["impact"] = {r=0.49, g=0.46, b=0.51, a=1},
	["sonic"] = {r=0.7, g=0.7, b=0.7, a=1},
	["ice"] = {r=0.34, g=0.12, b=0.7, a=1},
	["fusion"] = {r=0.02, g=0.12, b=0.4, a=1},
}
